@@ -274,6 +274,23 @@ sub test_role_tinycommons_tree {
         is_deeply([Code::Includable::Tree::NodeMethods::next_siblings($n5)], [$n6, $n7], "next_siblings [1] (sub call)");
         is_deeply([Code::Includable::Tree::NodeMethods::next_siblings($n7)], []        , "next_siblings [2] (sub call)");
 
+        # remove
+        {
+            my @children;
+
+            Code::Includable::Tree::NodeMethods::remove($n8);
+            @children = $n2->children;
+            if (@children == 1 && ref $children[0] eq 'ARRAY') { @children = @{ $children[0] } }
+            is_deeply(\@children, [])
+                or diag explain \@children;
+
+            Code::Includable::Tree::NodeMethods::remove($n6);
+            @children = $n1->children;
+            if (@children == 1 && ref $children[0] eq 'ARRAY') { @children = @{ $children[0] } }
+            is_deeply(\@children, [$n3, $n4, $n5, $n7])
+                or diag explain \@children;
+        }
+
     } if $args{test_nodemethods};
 }
 
@@ -292,7 +309,7 @@ Test::Role::TinyCommons::Tree - Test suite for Role::TinyCommons::Tree
 
 =head1 VERSION
 
-This document describes version 0.11 of Test::Role::TinyCommons::Tree (from Perl distribution Role-TinyCommons-Tree), released on 2016-11-23.
+This document describes version 0.120 of Test::Role::TinyCommons::Tree (from Perl distribution Role-TinyCommons-Tree), released on 2020-02-06.
 
 =head1 DESCRIPTION
 
@@ -362,7 +379,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Role-TinyC
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Role-TinyCommons-TreeNode>.
+Source repository is at L<https://github.com/perlancar/perl-Role-TinyCommons-Tree>.
 
 =head1 BUGS
 
@@ -378,7 +395,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
